/*
 * Build a compass module that displays the heading on LCD Display
 * @author Michael Burmeister
 * @date January 14, 2015
 * @version 1.0
 * 
*/

#include "simpletools.h"                      // Include simple tools
#include "compass.h"
#include "lcddisplay.h"


#define SCL 4
#define SDA 5
#define Rx 2
#define Tx 3
#define Baud 19200
char buffer[50];


int main()
{
  int lx, ly, lz, hx, hy, hz;
  int ox, oy, oz;
  float heading;
  
  lx = 1000;
  ly = 1000;
  lz = 1000;
  hx = -1000;
  hy = -1000;
  hz = -1000;

  int x, y, z;
  
  Compass_Open(SCL, SDA, MContinues);
  Lcd_Open(Baud, Rx, Tx);
  
  // Offset to make direction work
  ox = 315;
  oy = -4;
  oz = -890;
  
  // Changing Gain makes the numbers smaller
  Compass_SetGain(1);
  pause(1000);

  print("No, X, Y, Z, Degrees\n");
  Lcd_BackLight(LcdOn);
  
  for (int i=0;i<120;i++)
  {
    Compass_Read(&x, &y, &z);
    
    if (x < lx)
      lx = x;
    if (x > hx)
      hx = x;
    if (y < ly)
      ly = y;
    if (y > hy)
      hy = y;
    if (z < lz)
      lz = z;
    if (z > hz)
      hz = z;
    
    x -= ox;
    y -= oy;
    z -= oz;
    
    heading = atan2(y,x);
    if (heading < 0)
      heading += 2 * PI;
    
    heading = heading * 180/PI;
    
    print("%d, %d, %d, %d, %3.0f\n", i, x, y, z, heading);
    
    sprintf(buffer, "%3.0f", heading);
    Lcd_Clr();
    Lcd_Chrs(buffer);
    pause(250);
  }
  
  print("High xyz: %d, %d, %d\n", hx, hy, hz);
  print("Low xyz: %d, %d, %d\n", lx, ly, lz);
  
  x = (hx - lx)/2;
  y = (hy - ly)/2;
  z = (hz - lz)/2;
  print("Offset xyz: %d, %d, %d\n", hx-x, hy-y, hz-z);
  Lcd_Clr();
  pause(1000);
  Lcd_Close();
}
